@@ -139,6 +139,12 @@ class LHVQubit:
         new_y = 2 * (rho_prime[0][1].imag - rho_prime[1][0].imag)
         new_z = 2 * rho_prime[0][0].real - 1  # since Tr(ρ') = 1
 
+        p = math.sqrt(new_x**2 + new_y**2 + new_z**2)
+
+        new_x /= p
+        new_y /= p
+        new_z /= p
+
         self.bloch = [new_x, new_y, new_z]
 
     def prob(self, basis=Pauli.PauliZ):
@@ -202,7 +208,6 @@ class QrackAceBackend:
         sim(QrackSimulator): Array of simulators corresponding to "patches" between boundary rows.
         long_range_columns(int): How many ideal rows between QEC boundary rows?
         is_transpose(bool): Rows are long if False, columns are long if True
-        correction_bias(float): Bias magnitude and direction during pseudo-QEC
     """
 
     def __init__(
@@ -211,7 +216,6 @@ class QrackAceBackend:
         long_range_columns=4,
         long_range_rows=4,
         is_transpose=False,
-        correction_bias=0,
         isTensorNetwork=False,
         isSchmidtDecomposeMulti=False,
         isSchmidtDecompose=True,
@@ -240,7 +244,6 @@ class QrackAceBackend:
         self.long_range_columns = long_range_columns
         self.long_range_rows = long_range_rows
         self.is_transpose = is_transpose
-        self.correction_bias = correction_bias
 
         fppow = 5
         if "QRACK_FPPOW" in os.environ:
@@ -445,13 +448,13 @@ class QrackAceBackend:
 
     def _get_lhv_bloch_angles(self, sim):
         # Z axis
-        z = 1 - 2 * sim.prob(Pauli.PauliZ)
+        z = sim.bloch[2]
 
         # X axis
-        x = 1 - 2 * sim.prob(Pauli.PauliX)
+        x = sim.bloch[0]
 
         # Y axis
-        y = 1 - 2 * sim.prob(Pauli.PauliY)
+        y = sim.bloch[1]
 
         inclination = math.atan2(math.sqrt(x**2 + y**2), z)
         azimuth = math.atan2(y, x)
@@ -483,9 +486,7 @@ class QrackAceBackend:
 
         return azimuth, inclination
 
-    def _rotate_to_bloch(
-        self, hq, delta_azimuth, delta_inclination
-    ):
+    def _rotate_to_bloch(self, hq, delta_azimuth, delta_inclination):
         sim = self.sim[hq[0]]
         q = hq[1]
 
@@ -502,10 +503,7 @@ class QrackAceBackend:
 
         sim.mtrx([m00, m01, m10, m11], q)
 
-
-    def _rotate_lhv_to_bloch(
-        self, sim, delta_azimuth, delta_inclination
-    ):
+    def _rotate_lhv_to_bloch(self, sim, delta_azimuth, delta_inclination):
         # Apply rotation as "Azimuth, Inclination" (AI)
         cosA = math.cos(delta_azimuth)
         sinA = math.sin(delta_azimuth)
@@ -519,7 +517,6 @@ class QrackAceBackend:
 
         sim.mtrx([m00, m01, m10, m11])
 
-
     def _correct(self, lq, phase=False, skip_rotation=False):
         hq = self._unpack(lq)
 
@@ -591,12 +588,12 @@ class QrackAceBackend:
                 i_target /= 5
                 for x in range(5):
                     if x == 2:
-                        self._rotate_lhv_to_bloch(hq[x], a_target - a[x], i_target - i[x])
+                        self._rotate_lhv_to_bloch(
+                            hq[x], a_target - a[x], i_target - i[x]
+                        )
                     else:
                         self._rotate_to_bloch(hq[x], a_target - a[x], i_target - i[x])
 
-                self.apply_magnetic_bias([lq], self.correction_bias)
-
         else:
             # RMS
             p = [
@@ -634,12 +631,12 @@ class QrackAceBackend:
                 i_target /= 3
                 for x in range(3):
                     if x == 2:
-                        self._rotate_lhv_to_bloch(hq[x], a_target - a[x], i_target - i[x])
+                        self._rotate_lhv_to_bloch(
+                            hq[x], a_target - a[x], i_target - i[x]
+                        )
                     else:
                         self._rotate_to_bloch(hq[x], a_target - a[x], i_target - i[x])
 
-                self.apply_magnetic_bias([lq], self.correction_bias)
-
         if phase:
             for q in qb:
                 b = hq[q]
@@ -658,12 +655,16 @@ class QrackAceBackend:
                 if c == 2:
                     a, i = self._get_lhv_bloch_angles(h)
                     self._rotate_lhv_to_bloch(
-                        h, math.atan(math.tan(a) * b) - a, math.atan(math.tan(i) * b) - i
+                        h,
+                        math.atan(math.tan(a) * b) - a,
+                        math.atan(math.tan(i) * b) - i,
                     )
                 else:
                     a, i = self._get_bloch_angles(h)
                     self._rotate_to_bloch(
-                        h, math.atan(math.tan(a) * b) - a, math.atan(math.tan(i) * b) - i
+                        h,
+                        math.atan(math.tan(a) * b) - a,
+                        math.atan(math.tan(i) * b) - i,
                     )
 
     def u(self, lq, th, ph, lm):
